import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';

const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');

// RevenueUSD_billions 
const numberFormat = number =>
  	(Math.abs(Number(number))) + " $" ;


const render = data => {
  const pieData = pie().sort(null).value(d=>d.RevenueUSD_billions)(data);
  const colors = scaleOrdinal(schemeCategory10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(200)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.RevenueUSD_billions))
  	.on("mouseover", d => console.log(d.data.RevenueUSD_billions));
  //creation of piechart 
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  // changing the styles of company and showing companies list

  legend.append("rect").attr("width",22).attr("height",25)
  	.attr("fill", d => colors(d.data.RevenueUSD_billions));
  legend.append("text")
  	.attr("x", 28)
  	.attr("y", 18)
  	.attr("class","legend_text")
  	.text(d => d.data.Company);
  legend.append("text")
  	.attr("x", 260)
  	.attr("y", 20)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.RevenueUSD_billions));
}

// my dataset url

const csvUrl =
 'https://gist.githubusercontent.com/vagdevi-369/35f1b970191b2fe73cab476ff343b4d5/raw/205898d56c0c218c8d97e82f0515b1f6766913a2/ICE-7';


//Displaying the list of largest internet companies and added the data here
csv(csvUrl).then(csvData => {
    csvData.sort((data1, data2) => data2.RevenueUSD_billions-data1.RevenueUSD_billions);
    if (csvData) {
      render(csvData.slice(0, 10));
    }
});
